@@ -13,7 +13,7 @@ import paraselene.css.*;
 
 
 /**
- * 数を表す文字列。スレッドセーフです。
+ * 数を表す文字列。
  */
 public class NumberValue extends PlainText implements AttributeValuable, CSSValuable {
 	private static final long serialVersionUID = 2L;
@@ -106,7 +106,7 @@ public class NumberValue extends PlainText implements AttributeValuable, CSSValu
 	 * @param num	値。
 	 * @param unit	単位。
 	 */
-	public synchronized void setNumber( Sign sign, double num, Unit unit ) {
+	public void setNumber( Sign sign, double num, Unit unit ) {
 		if ( num < 0 )	sign = Sign.MINUS;
 		num = Math.abs( num );
 		sign_data = sign;
@@ -281,7 +281,7 @@ public class NumberValue extends PlainText implements AttributeValuable, CSSValu
 	 * 複製の作成。
 	 * @return 複製。
 	 */
-	public synchronized HTMLPart getReplica() {
+	public HTMLPart getReplica() {
 		return new NumberValue( sign_data, val, unit_data );
 	}
 
@@ -450,7 +450,7 @@ public class NumberValue extends PlainText implements AttributeValuable, CSSValu
 	 * @param p 加算値。
 	 * @return this。
 	 */
-	public synchronized NumberValue add( double p ) {
+	public NumberValue add( double p ) {
 		setNumber( val + p );
 		return this;
 	}
@@ -480,7 +480,7 @@ public class NumberValue extends PlainText implements AttributeValuable, CSSValu
 	 * @param p 減算値。
 	 * @return this。
 	 */
-	public synchronized NumberValue subtract( double p ) {
+	public NumberValue subtract( double p ) {
 		setNumber( val - p );
 		return this;
 	}
@@ -510,7 +510,7 @@ public class NumberValue extends PlainText implements AttributeValuable, CSSValu
 	 * @param p 乗算値。
 	 * @return this。
 	 */
-	public synchronized NumberValue multiply( double p ) {
+	public NumberValue multiply( double p ) {
 		setNumber( val * p );
 		return this;
 	}
@@ -541,7 +541,7 @@ public class NumberValue extends PlainText implements AttributeValuable, CSSValu
 	 * @param p 除算値。
 	 * @return this。
 	 */
-	public synchronized NumberValue divide( double p ) {
+	public NumberValue divide( double p ) {
 		if ( p == 0 )	return this;
 		setNumber( val / p );
 		return this;
