@@ -250,7 +250,7 @@ public abstract class Page implements Serializable {
 		buf = buf.append( "," );
 		buf = buf.append( new Date().toString() );
 		buf = buf.append( "] " );
-		Tag	meta = new Tag( "meta", false );
+		Tag	meta = new Tag( "meta", true );
 		meta.setAttribute( new Attribute( "name", "generator" ), new Attribute( "content", buf.toString() ) );
 		head.addHTMLPart( meta );
 	}
@@ -1021,7 +1021,7 @@ public abstract class Page implements Serializable {
 		if ( getMainTag() == null )	return;
 		firstOutput( req );
 		ajax_f = true;
-		if ( getAccessedMobile() == RequestParameter.Mobile.NO_MOBILE && getAccessedSearchEngine() == RequestParameter.SearchEngine.NO_SEARCHENGINE ) {
+		if ( !safari_f && getAccessedMobile() == RequestParameter.Mobile.NO_MOBILE && getAccessedSearchEngine() == RequestParameter.SearchEngine.NO_SEARCHENGINE ) {
 			AjaxSupport	ajax = getAjaxSupport();
 			Tag	head = getFirstTagByType( "head" );
 			Tag	body = getFirstTagByType( "body" );
@@ -1091,12 +1091,20 @@ public abstract class Page implements Serializable {
 	private static final String	AJAX_TARGET_ID = "paraseleneDragonsTail";
 	private static final String	AJAX_ADD_ID = "paraseleneDragonsHead";
 	private boolean ajax_f = false;
-	private transient RequestParameter	now_req;
-	private transient RequestParameter.Mobile			access_mobile;
-	private transient RequestParameter.SearchEngine	access_se;
+	private RequestParameter	now_req;
+	private RequestParameter.Mobile			access_mobile;
+	private RequestParameter.SearchEngine	access_se;
+	private boolean safari_f = false;
 
 	/**
-	 * フレームワークが使用します。
+	 * Ajax機能が利用可能であるか？以下の全てを満たす場合に true を返します。
+	 * <ul>
+	 * <li>{@link #getAjaxSupport()}で、AjaxSupport.NO 以外を返した場合。
+	 * <li>携帯アクセスではない。
+	 * <li>検索エンジンのクローラーではない。
+	 * <li>Safari からのアクセスではない。
+	 * </ul>
+	 * @return true:利用可能、false:利用不可。
 	 */
 	public boolean isAjax() { return ajax_f; }
 	
@@ -1108,6 +1116,10 @@ public abstract class Page implements Serializable {
 		if ( req != null ) {
 			access_mobile = req.judgeMobile();
 			access_se = req.judgeSearchEngine();
+			String[]	ua = req.getHeader( "User-Agent" );
+			if ( ua != null ) {
+				safari_f = ( ua[0].indexOf( "Chrome" ) == -1 && ua[0].indexOf( "Safari" ) >= 0 );
+			}
 		}
 	}
 
@@ -1151,9 +1163,10 @@ public abstract class Page implements Serializable {
 	}
 
 	/**
-	 * キャッシュ禁止指定。常に false を返します。
+	 * キャッシュ禁止指定。常に false を返します。<br>
 	 * ただし、getLastModified に null 以外を返すと、この戻り値は無視されます。
 	 * 必要に応じてオーバーライドして下さい。
+	 * ただし、特別な理由がない限り、false を返して下さい。
 	 * @return true:ブラウザキャッシュを禁止します、
 	 * false:ブラウザキャッシュを許可します。
 	 */
