@@ -17,7 +17,6 @@ import paraselene.css.*;
  * テキスト。<br>
  * 単純な文字列情報を持ちますが、HTMLのタグ種別に合わせ
  * 出力フォーマットを変換します。
- * スレッドセーフです。
  */
 public class Text extends PlainText implements AttributeValuable, CSSValuable {
 	private static final long serialVersionUID = 2L;
@@ -173,12 +172,18 @@ public class Text extends PlainText implements AttributeValuable, CSSValuable {
 		StringBuilder	buf = new StringBuilder();
 		char[]	line = str.toCharArray();
 		int	spc_cnt = 0;
+		boolean	clm_f = getAssignedTag() instanceof paraselene.tag.table.Column;
 		for ( int i = 0; i < line.length; i++ ) {
 			if ( line[i] == ' ' ) {
 				String	add = " ";
 				switch( mode ) {
 				case BODY:
-					add = ((spc_cnt % 2) == 0)?	"&nbsp;": " ";
+					if ( clm_f ) {
+						add = ((spc_cnt % 2) == 0)?	"&nbsp;": " ";
+					}
+					else {
+						add = ((spc_cnt % 2) == 1)?	"&nbsp;": " ";
+					}
 					break;
 				}
 				spc_cnt++;
@@ -241,7 +246,7 @@ public class Text extends PlainText implements AttributeValuable, CSSValuable {
 	 * @param add 追加文字列。
 	 * @return thisを返す。
 	 */
-	public synchronized Text append( String add ) {
+	public Text append( String add ) {
 		if ( add == null )	return this;
 		StringBuilder	buf = new StringBuilder( super.toString( StringMode.PLAIN ) );
 		buf = buf.append( add );
