@@ -19,7 +19,8 @@ class Null {
 	}
 }
 
-class JSONData {
+class JSONData implements Serializable {
+	private static final long serialVersionUID = 2L;
 	private String	name = null;
 	private Object	value = null;
 	private Object[]	mval = null;
@@ -73,6 +74,7 @@ class JSONData {
 		return buf.toString();
 	}
 
+	private JSONData(){}
 	JSONData( String n, Object val ) {
 		name = n;
 		if ( val == null ) {
@@ -124,7 +126,8 @@ class JSONData {
  * 任意のSerializableを実装したクラスをJSONに変換できます。
  * そのクラスはpublicでなければなりません。
  */
-public class JSON {
+public class JSON implements Serializable {
+	private static final long serialVersionUID = 2L;
 	private JSONData[]	data;
 	private Serializable	obj;
 
@@ -142,6 +145,7 @@ public class JSON {
 		return buf.toString();
 	}
 
+	private JSON(){}
 	/**
 	 * コンストラクタ。<br>
 	 * 任意のSerializableを実装したクラスオブジェクトをJSONに変換できます。
