@@ -7,6 +7,7 @@
 package paraselene.css;
 
 import paraselene.*;
+import paraselene.tag.*;
 
 /**
  * スタイルシートの属性値で、値の変更が可能なものを示します。
@@ -26,9 +27,9 @@ public interface CSSValuable extends Valuable {
 	HTMLPart getReplica();
 
 	/**
-	 * 所属ページの設定。
-	 * @param p ページ。
+	 * 所属先タグの設定。
+	 * @param t 所属先。
 	 */
-	void setPage( Page p );
+	void setAssignedTag( Tag t );
 }
 
