@@ -112,6 +112,21 @@ public class DynamicPage extends Page {
 	private static final String	START_XML = "<?xml";
 	private static final String START_DOCTYPE = "<!DOCTYPE";
 	private static final String START_HTML = "<html";
+	private static final String XML_ENCODE = "encoding";
+	private String xml_encode = null;
+
+	private void setXmlEncode( String str ) {
+		xml_encode = "UTF-8";
+		int	idx = str.indexOf( XML_ENCODE );
+		if ( idx < 0 )	return;
+		str = str.substring( idx + XML_ENCODE.length() );
+		idx = str.indexOf( '"' );
+		if ( idx < 0 )	return;
+		str = str.substring( idx + 1 );
+		idx = str.indexOf( '"' );
+		if ( idx < 0 )	return;
+		xml_encode = str.substring( 0, idx );
+	}
 
 	/**
 	 * XHTMLであるか検査を行う。
@@ -122,18 +137,37 @@ public class DynamicPage extends Page {
 		BufferedReader	r = new BufferedReader( new InputStreamReader( in ) );
 		boolean	xml = false;
 		StringBuilder	doc = null;
+		StringBuilder	xml_enc = null;
 		while( true ) {
 			String	line = r.readLine();
 			if ( line == null )	break;
 			line = line.trim() + " ";
 			if ( line.isEmpty() )	continue;
-			int	loc = line.indexOf( START_XML );
-			if ( loc >= 0 ) {
+			int	xml_loc = line.indexOf( START_XML );
+			if ( xml_loc >= 0 ) {
 				xml = true;
+				xml_enc = new StringBuilder();
 			}
+			if ( xml_enc != null ) {
+				String	sub = line;
+				if ( xml_loc > 0 ) {
+					sub = sub.substring( xml_loc );
+				}
+				int	end = sub.indexOf( '>' );
+				if ( end < 0 ) {
+					xml_enc = xml_enc.append( sub );
+				}
+				if ( end >= 0 ) {
+					xml_enc = xml_enc.append( sub.substring( 0, end + 1 ) );
+					setXmlEncode( xml_enc.toString() );
+					xml_enc = null;
+				}
+			}
+
 			int start = line.indexOf( START_DOCTYPE );
 			if ( start >= 0 ) {
 				doc = new StringBuilder();
+				xml_enc = null;
 			}
 			if ( doc != null ) {
 				if ( start > 0 ) {
@@ -288,10 +322,11 @@ public class DynamicPage extends Page {
 	/**
 	 * HTML解析時文字コードの取得。
 	 * 解析した際に使用した文字コードを返します。
-	 * @return 文字コード名。ただし、XHTMLだった時、meta タグで文字コードが
-	 * 指定されていなかった時、は null を返します。
+	 * @return 文字コード名。ただし、文字コードを判別出来なかった時はnull。
 	 */
-	public String getParsingCharset() { return parse_encode; }
+	public String getParsingCharset() {
+		return xml_encode == null?	parse_encode: xml_encode;
+	}
 
 	/**
 	 * HTML構築。
@@ -423,5 +458,7 @@ public class DynamicPage extends Page {
 	}
 
 	public AjaxSupport getAjaxSupport() { return AjaxSupport.NO; }
+
+	public void firstOutput( RequestParameter req ) throws PageException{}
 }
 
