@@ -86,5 +86,14 @@ public class Closure extends Forward implements AjaxForward {
 		buf = buf.append( "/" ).append( close_page.getUniqueKey() );
 		return buf.toString();
 	}
+
+	OutputCall makeOutput( int nk, Page lp, RequestParameter r, SessionData sd ) {
+		if ( close_page.getPopupType() == null ) {
+			Option.trace( "new LocationOutput <- %s", this );
+			return new LocationOutput( nk, lp, this, r, sd );
+		}
+		Option.trace( "new CloseOutput <- %s", this );
+		return new CloseOutput( nk, lp, this, r, sd );
+	}
 }
 
