@@ -20,7 +20,7 @@ public class Forward implements Serializable {
 	private static final long serialVersionUID = 2L;
 	private int	error = 0;
 	private URI	redirect_uri = null;
-	private PageID	out_page = null;
+	PageID	out_page = null;
 
 	private AjaxForward[]	ajax = null;
 	private AjaxForward		not_ajax = null;
@@ -110,6 +110,7 @@ public class Forward implements Serializable {
 
 	AjaxForward[] getAjaxForward( boolean ajax_f ) {
 		if ( ajax_f )	return ajax;
+		if ( not_ajax == null )	return null;
 		return new AjaxForward[]{ not_ajax };
 	}
 
@@ -171,11 +172,19 @@ public class Forward implements Serializable {
 	}
 
 	Page getPage( Page from ) {
-		if ( out_page == null )	return null;
-		if ( from != null ) {
-			if ( out_page == from.getID() )	return from;
+		if ( out_page == null ) {
+			Option.trace( "Forward#getPage -> null" );
+			return null;
 		}
-		return out_page.getPageFactory().getPage( out_page.getID() );
+		if ( from != null ) {
+			if ( out_page == from.getID() ) {
+				Option.trace( "Forward#getPage -> %s", from.getUniqueKey() );
+				return from;
+			}
+		}
+		Page	p = out_page.getPageFactory().getPage( out_page.getID() );
+		Option.trace( "Forward#getPage -> %s", p.getUniqueKey() );
+		return p;
 	}
 
 	/**
@@ -246,5 +255,10 @@ public class Forward implements Serializable {
 		}
 		return buf.toString();
 	}
+
+	OutputCall makeOutput( int nk, Page lp, RequestParameter r, SessionData sd ) {
+		Option.trace( "new LocationOutput <- %s", this );
+		return new LocationOutput( nk, lp, this, r, sd );
+	}
 }
 
