@@ -308,7 +308,11 @@ public class Option implements Serializable {
 					trace_writer.write( " " );
 					trace_writer.write( sta[i].toString() );
 					trace_writer.write( CR );
-					trace_writer.write( mes );
+					char[]	ch = mes.toCharArray();
+					for ( int j = 0; j < ch.length; j++ ) {
+						if ( ch[j] == '\n' )	trace_writer.write( CR );
+						else	trace_writer.write( ch[j] );
+					}
 					trace_writer.write( CR );
 					break;
 				}
@@ -327,7 +331,7 @@ public class Option implements Serializable {
 		catch( Exception e ) {}
 	}
 
-	static void append( String ... s ) {
+	static void appendTrace( String ... s ) {
 		if ( trace_writer == null )	return;
 		StringBuilder	buf = new StringBuilder();
 		for ( int i = 0; i < s.length; i++ ) {
