@@ -279,9 +279,7 @@ public abstract class Supervisor extends HttpServlet {
 			onError( e2 );
 		}
 		HttpSession	session = req.getSession( false );
-		if ( session != null ) {
-			clear_session( session );
-		}
+		clear_session( session );
 		return fw;
 	}
 	private Forward onErrorDebug( Throwable e, HttpServletRequest req, HttpServletResponse res ) {
@@ -289,13 +287,8 @@ public abstract class Supervisor extends HttpServlet {
 	}
 
 	private static void clear_session( HttpSession s ) {
-		s.invalidate();
+		if ( s != null )	s.invalidate();
 		Option.traceWithStack( "session cleared" );
-/*
-		if ( Option.isSpy() ) {
-			Thread.dumpStack();
-		}
-*/
 	}
 
 	/**
@@ -355,7 +348,7 @@ public abstract class Supervisor extends HttpServlet {
 							next_page = fw.getPage( null );
 							if ( next_page == null ) {
 								fw.Action( this, res );
-								if ( session_f )	if (session != null )	clear_session( session );
+								if ( session_f )	clear_session( session );
 								return;
 							}
 						}
@@ -370,14 +363,14 @@ public abstract class Supervisor extends HttpServlet {
 			if ( path_data == null ) {
 				fw = new Forward( 403 );
 				fw.Action( this, res );
-				if (session != null )	clear_session( session );
+				clear_session( session );
 				return;
 			}
 			if ( path_data.redirect != null ) {
 				if ( !holder.data.write( this, path_data.redirect, holder ) ) {
 					fw = new Forward( 403 );
 					fw.Action( this, res );
-					if (session != null )	clear_session( session );
+					clear_session( session );
 				}
 				return;
 			}
@@ -387,12 +380,18 @@ public abstract class Supervisor extends HttpServlet {
 			if ( ajax == null )	ajax = req.getItem( Form.FORM_AJAX );
 			if ( ajax != null ) {
 				String	call_key = ajax.getValue( 0 );
+				Option.trace( "call_key=%s", call_key );
 				Page	sub = data.hist.get( (path_data.from_histry != null)? path_data.from_histry: HistorySet.ROOT ).getBrowsingPage( call_key );
 				if ( sub != null ) {
 					fact.returnPage( last_page );
 					last_page = sub;
 				}
 				else if ( !"-1".equals( call_key ) ) {
+					fw = data.redirect( req.getURI() );
+					if ( fw != null ) {
+						fw.Action( this, res );
+						return;
+					}
 					fw = onIllegalRequest( IllegalRequest.SESSION_ERROR, req, last_page, next_page );
 					if ( fw == null || fw.getStatus() == 0 ) {
 						fw = new Forward( 403 );
@@ -408,7 +407,7 @@ public abstract class Supervisor extends HttpServlet {
 					System.out.println( "last page is null" );
 					fw = new Forward( 403 );
 					fw.Action( this, res );
-					if (session != null )	clear_session( session );
+					clear_session( session );
 					return;
 				}
 				if ( last_page.isAllowHistoryAdd() ) {
@@ -425,7 +424,7 @@ public abstract class Supervisor extends HttpServlet {
 							next_page = fw.getPage( null );
 							if ( next_page == null ) {
 								fw.Action( this, res );
-								if ( session_f )	if (session != null )	clear_session( session );
+								if ( session_f )	clear_session( session );
 								return;
 							}
 						}
@@ -440,14 +439,14 @@ public abstract class Supervisor extends HttpServlet {
 					System.out.println( "next page is null" );
 					fw = new Forward( 403 );
 					fw.Action( this, res );
-					if (session != null )	clear_session( session );
+					clear_session( session );
 					return;
 				}
 			}
 			else {
 				fw = new Forward( 403 );
 				fw.Action( this, res );
-				if (session != null )	clear_session( session );
+				clear_session( session );
 				return;
 			}
 
@@ -459,7 +458,7 @@ public abstract class Supervisor extends HttpServlet {
 					next_page = fw.getPage( null );
 					if ( next_page == null ) {
 						fw.Action( this, res );
-						if ( session_f )	if (session != null )	clear_session( session );
+						if ( session_f )	clear_session( session );
 						return;
 					}
 				}
@@ -509,7 +508,7 @@ public abstract class Supervisor extends HttpServlet {
 				}
 				if ( (!last_page.isAjax() && fw.isLeave()) || fw.getStatus() != 0 ) {
 					fw.Action( this, res );
-					if ( session_f )	if (session != null )	clear_session( session );
+					if ( session_f )	clear_session( session );
 					return;
 				}
 			}
@@ -517,7 +516,7 @@ public abstract class Supervisor extends HttpServlet {
 			if ( path_data.to_histry != null ) {
 				out_hist_key = path_data.to_histry;
 			}
-			OutputHolder	oh = new OutputHolder( out_hist_key, last_page, fw, req, data );
+			OutputHolder	oh = new OutputHolder( ajax != null && last_page.isAjax(), out_hist_key, last_page, fw, req, data );
 			oh.call();
 			String	key = last_page.getUniqueKey();
 			ajax = req.getItem( A_AJAX_KEY );
@@ -600,7 +599,7 @@ public abstract class Supervisor extends HttpServlet {
 			session = null;
 		}
 		if ( session_f ) {
-			if ( session != null )	clear_session( session );
+			clear_session( session );
 			session = null;
 		}
 		else if ( session == null ) {
@@ -647,6 +646,7 @@ public abstract class Supervisor extends HttpServlet {
 				try {
 					if ( date.compareTo( new HTTPDate( mod[0] ) ) <= 0 ) {
 						res.sendError( 304 );
+						res.setContentType( mime );
 						data.hist.get( next_page.getHistoryKey() ).add( next_page );
 						return;
 					}
@@ -829,7 +829,27 @@ public abstract class Supervisor extends HttpServlet {
 			return onErrorDebug( e, request, res, 422 );
 		}
 		req.setParam( method, request, this );
-		Option.trace( "client access %s", req.getURI() );
+
+		String[]	header = req.getHeaderNames();
+		ArrayList<String>	log = new ArrayList<String>();
+		StringBuilder	buf = new StringBuilder( "client access\n" );
+		buf = buf.append( req.getMethod().toString() );
+		buf = buf.append( " " );
+		buf = buf.append( req.getURI() );
+		buf = buf.append( "\n" );
+		log.add( buf.toString() );
+		for ( int i = 0; i < header.length; i++ ) {
+			String[]	val = req.getHeader( header[i] );
+			for ( int  j = 0; j < val.length; j++ ) {
+				buf = new StringBuilder( header[i] );
+				buf = buf.append( " : " );
+				buf = buf.append( val[j] );
+				buf = buf.append( "\n" );
+				log.add( buf.toString() );
+			}
+		}
+		Option.appendTrace( log.toArray( new String[0] ) );
+
 		holder.search_engine = req.judgeSearchEngine() != RequestParameter.SearchEngine.NO_SEARCHENGINE;
 		holder.request = req;
 
