@@ -48,7 +48,7 @@ public class CheckBox extends Input {
 	}
 
 	protected Tag newReplica() {
-		return new CheckBox( radio_flag );
+		return copy4Replica( new CheckBox( radio_flag ) );
 	}
 
 	/**
