@@ -69,7 +69,7 @@ public class Input extends Control {
 	}
 
 	protected Tag newReplica() {
-		return new Input( input_type );
+		return copy4Replica( new Input( input_type ) );
 	}
 
 	/**
