@@ -39,7 +39,7 @@ public class SingleTextBox extends Input {
 	}
 
 	protected Tag newReplica() {
-		return new SingleTextBox( password_f );
+		return copy4Replica( new SingleTextBox( password_f ) );
 	}
 
 	/**
