@@ -45,7 +45,7 @@ public class UploadFile extends Input {
 	}
 
 	protected Tag newReplica() {
-		return new UploadFile();
+		return copy4Replica( new UploadFile() );
 	}
 
 	void setRequest( RequestItem item ) {
@@ -71,6 +71,19 @@ public class UploadFile extends Input {
 		return mime;
 	}
 
+	/**
+	 * ファイルの大きさの取得。
+	 * 一時ファイルのファイル長を得ます。
+	 * 一時ファイルが削除されていると 0 を返します。
+	 * @return 一時ファイルの大きさ。
+	 */
+	public long length() {
+		if ( file != null ) {
+			return file.length();
+		}
+		return 0;
+	}
+
 	/**
 	 * 一時ファイルの削除。既に削除されていれば何もしません。
 	 */
